// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
var app = angular.module('myApp', ['ionic', 'ngCordova'])
  .directive('hideTabs', function ($rootScope) {
    return {
      restrict: 'A',
      link: function (scope, element, attributes) {
        scope.$on('$ionicView.beforeEnter', function () {
          scope.$watch(attributes.hideTabs, function (value) {
            $rootScope.hideTabs = value;
          });
        });
        scope.$on('$ionicView.beforeLeave', function () {
          $rootScope.hideTabs = false;
        });
      }
    };
  })

  .run(function ($state, $ionicHistory, $location, homeService, $cordovaAppVersion, $ionicActionSheet, $timeout, $cordovaFileOpener2, $cordovaFileTransfer, $ionicLoading, $ionicPlatform, $rootScope, $cordovaToast, $ionicPopup) {
    $ionicPlatform.ready(function () {
      // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
      // for form inputs)
      if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        cordova.plugins.Keyboard.disableScroll(true);

      }
      if (window.StatusBar) {
        // org.apache.cordova.statusbar required
        StatusBar.styleDefault();
      }
      try {
        //啟動頁面消失
        navigator.splashscreen.hide();
      }
      catch (e) {
      }
      //listen for Offline event
      $rootScope.$on('$cordovaNetwork:offline', function (event, networkState) {
        $cordovaToast.showShortBottom('网络异常！请检查设备是否可以联网！');
      });

      try {
        checkUpdate();
      } catch (e) {
        console.log("手机端在电脑显示错误");
      }
      // 检查更新
      function checkUpdate() {
        homeService.fnEditionGet()
          .then(function (datas) {
            var serverAppVersion = datas; //从服务端获取最新版本
            try {
              //获取版本
              cordova.getAppVersion.getVersionNumber().then(function (version) {
                //alert("verson:"+_version)
                //如果本地于服务端的APP版本不符合
                if (version != serverAppVersion) {
                  showUpdateConfirm(serverAppVersion);
                }
              });
            } catch (e) {
              console.log("手机端在电脑显示插件错误");
            }
          }, function (error) {
            $cordovaToast.showShortBottom('网络出现异常！');
          });

        //获取版本
        cordova.getAppVersion.getVersionNumber().then(function (version) {
          //alert("verson:"+_version)
          //如果本地于服务端的APP版本不符合
          if (version != serverAppVersion) {
            showUpdateConfirm(serverAppVersion);
          }
        });
      }


      // 显示是否更新对话框
      function showUpdateConfirm(serverAppVersion) {
        //var permissions = cordova.plugins.permissions;
        //permissions.hasPermission(permissions.WRITE_EXTERNAL_STORAGE, checkPermissionCallback, null);
        //function checkPermissionCallback(status) {
        //  if (!status.hasPermission) {
        //    var errorCallback = function () {
        //      alert("错误")
        //    }
        //
        //    permissions.requestPermission(
        //      permissions.WRITE_EXTERNAL_STORAGE,
        //      function (status) {
        //        if (!status.hasPermission) errorCallback();
        //      },
        //      errorCallback);
        //  }
        //}

        var confirmPopup = $ionicPopup.confirm({
          title: '版本升级',
          subTitle: '新版本：' + serverAppVersion,
          template: '1.修复已知bug;</br></br><p>建议在WiFi下更新;</p>', //从服务端获取更新的内容
          cancelText: '暂不升级',
          okText: '立即安装'
        });
        confirmPopup.then(function (res) {
            if (res) {
              $ionicLoading.show({
                template: "已经下载：0%"
              });

              var permissions = cordova.plugins.permissions;
              permissions.hasPermission(permissions.WRITE_EXTERNAL_STORAGE, checkPermissionCallback, null);
              function checkPermissionCallback(status) {
                if (!status.hasPermission) {
                  var errorCallback = function () {
                    $cordovaToast.showShortBottom('需要文件操作权限！');
                    $ionicLoading.hide();
                  };
                  permissions.requestPermission(permissions.WRITE_EXTERNAL_STORAGE, function (status) {
                    if (!status.hasPermission) {
                      errorCallback();
                    } else {
                      //确认选择了权限，开始下载
                      downLoadApps();
                    }
                  }, errorCallback);
                }
                else {//已有权限，开始下载
                  downLoadApps();
                }
              }

            }

            else {
              // 取消更新
            }
          }
        );
      }

      //下载方法
      function downLoadApps() {
        var url = "http://www.lekaowang.cn/android-debug.apk"; //可以从服务端获取更新APP的路径
        var targetPath = cordova.file.externalRootDirectory + "Download/android-debug.apk"; //APP下载存放的路径，可以使用cordova file插件进行相关配置
        var trustHosts = true
        var options = {};
        $cordovaFileTransfer.download(url, targetPath, options, trustHosts).then(function (result) {
          // 打开下载下来的APP
          $cordovaFileOpener2.open(targetPath, 'application/vnd.android.package-archive'
          ).then(function () {
            // 成功
            //alert("成功")
          }, function (err) {
            // 错误
            //alert("错误")
          });
          $ionicLoading.hide();
        }, function (err) {
          alert("错误" + JSON.stringify(err))
          $ionicLoading.hide();
          $cordovaToast.showShortBottom('下载失败！');
        }, function (progress) {
          //进度，这里使用文字显示下载百分比
          //$timeout(function () {
          var downloadProgress = (progress.loaded / progress.total) * 100;
          $ionicLoading.show({
            template: "已经下载：" + Math.floor(downloadProgress) + "%"
          });
          if (downloadProgress > 99) {
            $ionicLoading.hide();
          }
          //})
        });

      }

      //双击退出
      $ionicPlatform.registerBackButtonAction(function (e) {
        if ($location.path().substring(0, 11) == '/my/billPay') {
          //alert("path---->"+$location.path().substring(0, 15))
          $state.go('billList');
        } else
        //判断回listDetail页面
        if ($location.path().substring(0, 15) == '/tab/listDetail') {
          //alert("path---->"+$location.path().substring(0, 15))
          $ionicHistory.goBack(-1);//返回前一个视图
        } else
        //判断回home页面 新增直播页回首页 2017/10/30
        if ($location.path().substring(0, 9) == '/tab/list' || $location.path().substring(0, 15) == '/tab/homeDetail' || $location.path() == '/tab/userLogin' || $location.path() == '/tab/liveBroadcast') {
          //alert("path---->"+$location.path())
          $state.go('tab.home');
        } else
        //判断回person页面 新增回归person 2017/10/31
        if ($location.path() == '/my/myLiveBroadcast' || $location.path() == '/my/course' || $location.path() == '/my/test' || $location.path() == '/my/review' || $location.path() == '/my/spotQuestions' || $location.path() == '/my/videoCourseList' || $location.path() == '/my/answeringQuestion' || $location.path() == '/my/contractList' || $location.path() == '/my/billList' || $location.path() == '/my/videoDownload') {
          $state.go('tab.person');
        } else
        //判断处于哪个页面时双击退出
        if ($location.path() == '/tab/home' || $location.path() == '/tab/wikipedia' || $location.path() == '/tab/shop' || $location.path() == '/tab/person') {
          if ($rootScope.backButtonPressedOnceToExit) {
            ionic.Platform.exitApp();
          } else {
            $rootScope.backButtonPressedOnceToExit = true;
            $cordovaToast.showShortBottom('再按一次退出系统');
            setTimeout(function () {
              $rootScope.backButtonPressedOnceToExit = false;
            }, 2000);
          }
        }
        else if ($ionicHistory.backView()) {
          $ionicHistory.goBack();
        } else {
          $rootScope.backButtonPressedOnceToExit = true;
          //$cordovaToast.showShortBottom('再按一次退出系统');
          setTimeout(function () {
            $rootScope.backButtonPressedOnceToExit = false;
          }, 2000);
        }
        e.preventDefault();
        return false;
      }, 101);


      //启动极光推送服务
      window.plugins.jPushPlugin.init();

      //调试模式
      window.plugins.jPushPlugin.setDebugMode(true);

    });

  });
